import type { Metadata } from "next";
import "../globals.css";
import { NextIntlClientProvider } from 'next-intl';
import { getMessages } from 'next-intl/server';
import {notFound} from 'next/navigation';
import {routing} from '@/i18n/routing';
import { inter_sans } from "../_client/libs/fonts";
import { Header } from "../_client/components/layout/header";
import { Footer } from "../_client/components/layout/footer";
import { ToastContainer } from "react-toastify";
import 'react-toastify/dist/ReactToastify.css';
import { ThemeProvider } from "next-themes";
import Script from "next/script";


export const metadata: Metadata = {
  title: "Create Next App",
  description: "Generated by create next app",
};

type LayoutProps = {
  children: React.ReactNode
  params: Promise<{
    locale: string
  }>
}

const Layout = async({ children, params }: LayoutProps) => {
  const { locale } = await params

  if (!routing.locales.includes(locale as any)) {
    notFound();
  }
 
  const messages = await getMessages();

  return (
      <html suppressHydrationWarning lang={locale}>
        <Script src="https://cdnjs.cloudflare.com/ajax/libs/iframe-resizer/4.3.9/iframeResizer.min.js"></Script>
        <body className={`${ inter_sans } font-inter bg-body dark:bg-dark_body`}>
          <ThemeProvider attribute="class">
            <NextIntlClientProvider messages={messages}>
              <Header />
              {children}
              <ToastContainer autoClose={3000} />
              <Footer />
            </NextIntlClientProvider>
          </ThemeProvider>
        </body>
      </html>
  );
}


export default Layout